@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2007 Steven L. Scott
 
@@ -19,36 +20,34 @@
 #ifndef BOOM_LOGIT_SAMPLER_BMA_HPP
 #define BOOM_LOGIT_SAMPLER_BMA_HPP
 
-#include <Models/Glm/PosteriorSamplers/LogitSampler.hpp>
-#include <Models/Glm/VariableSelectionPrior.hpp>
+#include "Models/Glm/PosteriorSamplers/LogitSampler.hpp"
+#include "Models/Glm/VariableSelectionPrior.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-  class LogitSamplerBma
-    : public LogitSampler{
-  public:
-    LogitSamplerBma(LogisticRegressionModel *mod,
-            Ptr<MvnBase>,
-            Ptr<VariableSelectionPrior>,
-            RNG &seeding_rng = GlobalRng::rng);
+  class LogitSamplerBma : public LogitSampler {
+   public:
+    LogitSamplerBma(LogisticRegressionModel *mod, const Ptr<MvnBase> &slab,
+                    const Ptr<VariableSelectionPrior> &spike,
+                    RNG &seeding_rng = GlobalRng::rng);
 
     void draw() override;
     double logpri() const override;
 
     void limit_model_selection(uint n);
-    double log_model_prob(const Selector &inc)const;
-  private:
+    double log_model_prob(const Selector &inc) const;
+
+   private:
     void draw_beta_given_gamma();
     void draw_gamma();
 
     LogisticRegressionModel *mod_;
-    Ptr<MvnBase> pri_;
-    Ptr<VariableSelectionPrior> vs_;
+    Ptr<MvnBase> slab_;
+    Ptr<VariableSelectionPrior> spike_;
     uint max_nflips_;
 
     mutable SpdMatrix Ominv, iV_tilde_;
-
   };
 
-}
-#endif // BOOM_LOGIT_SAMPLER_BMA_HPP
+}  // namespace BOOM
+#endif  // BOOM_LOGIT_SAMPLER_BMA_HPP
