@@ -269,6 +269,32 @@ namespace BOOM {
     return std::tuple<double, uint, uint>(num / denom, imax, jmax);
   }
 
+  double relative_distance(const Matrix &A, const Matrix &B, int &imax, int &jmax) {
+    if (A.nrow() != B.nrow() || A.ncol() != B.ncol()) {
+      return infinity();
+    }
+    imax = jmax = -1;
+    double max_distance = negative_infinity();
+    for (int i = 0; i < A.nrow(); ++i) {
+      for (int j = 0; j < A.ncol(); ++j) {
+        double num = fabs(A(i, j) - B(i, j));
+        double denom = fabs(A(i, j)) + fabs(B(i, j));
+        double crit = denom <= 0 ? 0.0 : .5 * num / denom;
+        if (crit > max_distance) {
+          imax = i;
+          jmax = j;
+          max_distance = crit;
+        }
+      }
+    }
+    return max_distance;
+  }
+
+  double relative_distance(const Matrix &A, const Matrix &B) {
+    int imax = -1, jmax = -1;
+    return relative_distance(A, B, imax, jmax);
+  }
+
   bool Matrix::is_sym(double tol) const {
     double dist;
     uint imax, jmax;
@@ -1078,6 +1104,26 @@ namespace BOOM {
 
   void print(const Matrix &m) { std::cout << m << std::endl; }
 
+  std::string to_Rstring(const Matrix &m) {
+    std::ostringstream out;
+    if (m.size() == 0) {
+      out << "numeric(0)";
+    } else {
+      out << "matrix(c(";
+      for (int i = 0; i < m.nrow(); ++i) {
+        for (int j = 0; j < m.ncol(); ++j){
+          if (i > 0 || j > 0) {
+            out << ", ";
+          }
+          out << m(i, j);
+        }
+      }
+      out << "), nrow = "
+          << m.nrow() << ", byrow=TRUE)";
+    }
+    return out.str();
+  }
+
   std::istream &operator>>(std::istream &in, Matrix &m) {
     // reads until a blank line is found or the end of a line
 
