@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2015 Steven L. Scott
 
@@ -16,21 +17,18 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Models/Glm/ZeroInflatedPoissonRegression.hpp>
-#include <distributions.hpp>
-#include <cpputil/report_error.hpp>
+#include "Models/Glm/ZeroInflatedPoissonRegression.hpp"
+#include "cpputil/report_error.hpp"
+#include "distributions.hpp"
 
 namespace BOOM {
 
   ZeroInflatedPoissonRegressionData::ZeroInflatedPoissonRegressionData(
-      int64_t y,
-      const Vector &x,
-      int64_t total_number_of_trials,
+      int64_t y, const Vector &x, int64_t total_number_of_trials,
       int64_t number_of_zero_trials)
       : PoissonRegressionData(y, x, total_number_of_trials),
         number_of_zeros_(number_of_zero_trials),
-        number_of_trials_(total_number_of_trials)
-  {
+        number_of_trials_(total_number_of_trials) {
     if (number_of_zero_trials < 0) {
       report_error("Number of trials must be non-negative.");
     }
@@ -52,12 +50,12 @@ namespace BOOM {
   }
 
   void ZeroInflatedPoissonRegressionData::add_incremental_data(
-      int64_t incremental_event_count,
-      int64_t incremental_number_of_trials,
+      int64_t incremental_event_count, int64_t incremental_number_of_trials,
       int64_t incremental_number_of_zeros) {
     if (incremental_number_of_zeros > incremental_number_of_trials) {
-      report_error("Number of trials producing zero events cannot "
-                   "exceed the total number of trials.");
+      report_error(
+          "Number of trials producing zero events cannot "
+          "exceed the total number of trials.");
     }
     if (incremental_number_of_trials < 0) {
       report_error("The number of trials must be non-negative.");
@@ -66,26 +64,27 @@ namespace BOOM {
       report_error("The number of incremental events must be non-negative");
     }
     if (incremental_number_of_zeros < 0) {
-      report_error("The number of incremental zero-trials must "
-                   "be non-negative");
+      report_error(
+          "The number of incremental zero-trials must "
+          "be non-negative");
     }
     if (incremental_number_of_trials == 0 && incremental_event_count > 0) {
-      report_error("Postive incremental event count "
-                   "but zero incremental trials.");
+      report_error(
+          "Postive incremental event count "
+          "but zero incremental trials.");
     }
     number_of_zeros_ += incremental_number_of_zeros;
     number_of_trials_ += incremental_number_of_trials;
-    PoissonRegressionData::set_exposure(
-        exposure() + incremental_number_of_trials);
+    PoissonRegressionData::set_exposure(exposure() +
+                                        incremental_number_of_trials);
     set_y(y() + incremental_event_count);
   }
   //======================================================================
   typedef ZeroInflatedPoissonRegressionModel ZIPRM;
   ZIPRM::ZeroInflatedPoissonRegressionModel(int dimension)
-      : ParamPolicy(new GlmCoefs(dimension), new GlmCoefs(dimension))
-  {}
+      : ParamPolicy(new GlmCoefs(dimension), new GlmCoefs(dimension)) {}
 
-  ZIPRM * ZIPRM::clone() const { return new ZIPRM(*this); }
+  ZIPRM *ZIPRM::clone() const { return new ZIPRM(*this); }
 
   double ZIPRM::expected_value(const Vector &x) const {
     return probability_unconstrained(x) * poisson_mean(x);
@@ -103,21 +102,13 @@ namespace BOOM {
     return plogis(logit_coefficients().predict(x), 0, 1, false);
   }
 
-  Ptr<GlmCoefs> ZIPRM::poisson_coefficient_ptr() {
-    return prm1();
-  }
+  Ptr<GlmCoefs> ZIPRM::poisson_coefficient_ptr() { return prm1(); }
 
-  const GlmCoefs & ZIPRM::poisson_coefficients() const {
-    return prm1_ref();
-  }
+  const GlmCoefs &ZIPRM::poisson_coefficients() const { return prm1_ref(); }
 
-  Ptr<GlmCoefs> ZIPRM::logit_coefficient_ptr() {
-    return prm2();
-  }
+  Ptr<GlmCoefs> ZIPRM::logit_coefficient_ptr() { return prm2(); }
 
-  const GlmCoefs & ZIPRM::logit_coefficients() const {
-    return prm2_ref();
-  }
+  const GlmCoefs &ZIPRM::logit_coefficients() const { return prm2_ref(); }
 
   double ZIPRM::sim(const Vector &x, RNG &rng) const {
     if (runif_mt(rng) < probability_forced_to_zero(x)) {
@@ -126,12 +117,14 @@ namespace BOOM {
     return rpois(poisson_mean(x));
   }
 
-  ZeroInflatedPoissonSuf ZIPRM::simulate_sufficient_statistics(
-      const Vector &x, int64_t n, RNG &rng) const {
+  ZeroInflatedPoissonSuf ZIPRM::simulate_sufficient_statistics(const Vector &x,
+                                                               int64_t n,
+                                                               RNG &rng) const {
     double number_of_zeros = rbinom_mt(rng, n, probability_forced_to_zero(x));
     double number_of_positives = n - number_of_zeros;
-    double sum_of_positives = rpois_mt(rng, number_of_positives * poisson_mean(x));
-    return ZeroInflatedPoissonSuf(
-        number_of_zeros, number_of_positives, sum_of_positives);
+    double sum_of_positives =
+        rpois_mt(rng, number_of_positives * poisson_mean(x));
+    return ZeroInflatedPoissonSuf(number_of_zeros, number_of_positives,
+                                  sum_of_positives);
   }
-}
+}  // namespace BOOM
