@@ -15,54 +15,50 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/IRT/SubjectSliceSampler.hpp>
-#include <Models/IRT/Subject.hpp>
-#include <Models/IRT/SubjectPrior.hpp>
+#include "Models/IRT/SubjectSliceSampler.hpp"
+#include "Models/IRT/Subject.hpp"
+#include "Models/IRT/SubjectPrior.hpp"
 
-#include <Samplers/SliceSampler.hpp>
+#include "Samplers/SliceSampler.hpp"
 
-#include <cpputil/ParamHolder.hpp>
-#include <cpputil/math_utils.hpp>
+#include "cpputil/ParamHolder.hpp"
+#include "cpputil/math_utils.hpp"
 
-namespace BOOM{
-  namespace IRT{
+namespace BOOM {
+  namespace IRT {
 
     typedef SubjectTF TF;
-    TF::SubjectTF(Ptr<Subject> s, Ptr<SubjectPrior> p)
-      : sub(s),
-    pri(p),
-    prms(sub->Theta_prm()),
-    wsp(sub->Theta())
-    {}
+    SubjectTF::SubjectTF(const Ptr<Subject> &subject,
+                         const Ptr<SubjectPrior> &prior)
+        : sub(subject), pri(prior), prms(sub->Theta_prm()), wsp(sub->Theta()) {}
 
-    double TF::operator()(const Vector &v)const{
+    double SubjectTF::operator()(const Vector &v) const {
       ParamHolder ph(v, prms, wsp);
       double ans = pri->pdf(sub, true);
-      if(ans==BOOM::negative_infinity()) return ans;
-      ans+= sub->loglike();
+      if (ans == BOOM::negative_infinity()) return ans;
+      ans += sub->loglike();
       return ans;
     }
 
     //======================================================================
 
     typedef SubjectSliceSampler SSS;
-    SSS::SubjectSliceSampler(Ptr<Subject> s, Ptr<SubjectPrior> p,
+    SSS::SubjectSliceSampler(const Ptr<Subject> &s, const Ptr<SubjectPrior> &p,
                              RNG &seeding_rng)
-      : PosteriorSampler(seeding_rng),
-  sub(s),
-    pri(p),
-    target(sub, pri),
-    sam(new SliceSampler(target))
-    { }
+        : PosteriorSampler(seeding_rng),
+          sub(s),
+          pri(p),
+          target(sub, pri),
+          sam(new SliceSampler(target)) {}
 
-    SSS * SSS::clone()const{return new SSS(*this);}
+    SSS *SSS::clone() const { return new SSS(*this); }
 
-    void SSS::draw(){
+    void SSS::draw() {
       Theta = sam->draw(sub->Theta());
       sub->set_Theta(Theta);
     }
 
-    double SSS::logpri()const{ return pri->pdf(sub, true);}
+    double SSS::logpri() const { return pri->pdf(sub, true); }
 
-  }
-}
+  }  // namespace IRT
+}  // namespace BOOM
