@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2015 Steven L. Scott
 
@@ -16,20 +17,18 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
 
-#include <Samplers/RejectionSampler.hpp>
-#include <distributions.hpp>
-#include <cpputil/math_utils.hpp>
+#include "Samplers/RejectionSampler.hpp"
+#include "cpputil/math_utils.hpp"
+#include "distributions.hpp"
 
 namespace BOOM {
 
-  RejectionSampler::RejectionSampler(
-      const Target &log_target_density,
-      const Ptr<DirectProposal> &proposal)
+  RejectionSampler::RejectionSampler(const Target &log_target_density,
+                                     const Ptr<DirectProposal> &proposal)
       : log_target_density_(log_target_density),
         proposal_(proposal),
         log_proposal_density_offset_(0.0),
-        rejection_limit_(-1)
-  {}
+        rejection_limit_(-1) {}
 
   Vector RejectionSampler::draw(RNG &rng) {
     std::int64_t rejection_count = 0;
@@ -43,9 +42,8 @@ namespace BOOM {
         // Avoid the fact that the RNG is on U[0, 1).
         u = runif_mt(rng, 0, 1);
       }
-      if (log(u) < log_target_density_(candidate)
-          - proposal_->logp(candidate)
-          - log_proposal_density_offset_) {
+      if (log(u) < log_target_density_(candidate) - proposal_->logp(candidate) -
+                       log_proposal_density_offset_) {
         return candidate;
       }
     }
@@ -59,5 +57,4 @@ namespace BOOM {
     log_proposal_density_offset_ = offset;
   }
 
-
 }  // namespace BOOM
